% Summary1

% 1a. read and do cumulative plot of the 18 sources load timeseries
% 1b. " " but NOT cumulative (linear and log)
% 2. re-generate one pager plots for all 18 (so they are in one place)
% 3. save conc/flow/load results in mat, xlsx formats

% basic initial setup
wipe;
modprelims;

% retrieve inputs
ingrps = { 'Config'; }; inputsdiary;

%% read data from its various original locations and sort by source size
ddn = datenum(2001,1,1):datenum(endyr,12,31);
allTNloads = nan*ones(18,length(ddn));
nam = cell(18,1);
titl = cell(18,1);
for i = 1:18
    load([src{i}{2} src{i}{1}],'TNload','TNconc','Qflow');
    allTNloads(i,:) = TNload; % lb/yr (not 1000 lb/yr)
    allTNconcs(i,:) = TNconc;
    allQflows(i,:) = Qflow;
    titl{i} = src{i}{3};
    nam{i} = src{i}{1};
    clear TNload TNconc Qflow;
end

% sort based on long term mean TN load
mns = mean(allTNloads')';
[mns,ind] = sort(mns,'descend');
nam = nam(ind);
titl = titl(ind);
allTNloads = allTNloads(ind,:);
allTNconcs = allTNconcs(ind,:);
allQflows = allQflows(ind,:);
clear ind TNload TNconc Qflow;

%% 1a. cumulative plot (loads)
figland('on');
axes;
hold;
% calc cumsum and convert from lb/yr to 1000 lb/yr
loads = 0.001*cumsum([zeros(size(ddn)); allTNloads;]);
clr = distinguishable_colors(18);
for i = 1:18
    fprintf('plotting source %d: %s\n',i,nam{i});
    lh(i) = fill([ddn fliplr(ddn)],[loads(i,:) ...
        fliplr(loads(i+1,:))],...
        clr(i,:),'linestyle','none');
    % plot(ddn,loads(i+1,:),'k');
end
ax = gca;
% remove 10^x y-axis scaling
ax.YAxis.Exponent = 0;
% format yticklabels to include commas
lbl = get(gca,'yticklabel');
for i = 1:length(lbl)
    lbl{i} = addComma(num2str(str2num(lbl{i})));
end
set(gca,'yticklabel',lbl);
clear lbl i;
datetick;
set(gca,'xlim',[ddn(1) ddn(end)]);
legend(lh,titl);
ylabel('TN Load [1000 lb yr^{-1}]');
grid on;
%% right y-axis
yaxlim = get(gca,'ylim'); % 1000 lb/yr
yyaxis right;
ax = gca;
yax = ax.YAxis(2);
yax.Limits = yaxlim*453.592;  % kg/yr
pause(5); % ugh - so plotting can catch up
expn = double(yax.Exponent);
yax.Limits = yaxlim*453.592/10^expn;
if expn ~= 0
    ylabel(sprintf('TN Load [10^{%d} kg yr^{-1}]',expn));
else
    ylabel('TN Load [kg yr^{-1}]');
end
ax.YAxis(2).Color = 'k';
set(gcf,'PaperOrientation','Portrait');
print -dpng plt/cumulative;
delete(gcf);
clear expn yax ax lh clr yaxlim;

% 1b. plot (loads) - linear
figland('on');
axes;
hold;
clr = distinguishable_colors(18);
for i = 1:18
    fprintf('plotting source %d: %s\n',i,nam{i});
    lh(i) = plot(ddn,0.001*allTNloads(i,:)); % 1000 lb/yr
    set(lh(i),'color',clr(i,:));
end
ax = gca;
% remove 10^x y-axis scaling
ax.YAxis.Exponent = 0;
% format yticklabels to include commas
lbl = get(gca,'yticklabel');
for i = 1:length(lbl)
    lbl{i} = addComma(num2str(str2num(lbl{i})));
end
set(gca,'yticklabel',lbl);
clear lbl i;
datetick;
set(gca,'xlim',[ddn(1) ddn(end)]);
legend(lh,titl);
ylabel('TN Load [1000 lb yr^{-1}]');
grid on;
box on;
%% right y-axis
yaxlim = get(gca,'ylim'); % 1000 lb/yr
yyaxis right;
ax = gca;
yax = ax.YAxis(2);
yax.Limits = yaxlim*453.592;  % kg/yr
pause(5);
expn = double(yax.Exponent);
yax.Limits = yaxlim*453.592/10^expn;
if expn ~= 0
    ylabel(sprintf('TN Load [10^{%d} kg yr^{-1}]',expn));
else
    ylabel('TN Load [kg yr^{-1}]');
end
ax.YAxis(2).Color = 'k';
set(gcf,'PaperOrientation','Portrait');
print -dpng plt/lines-lin;
delete(gcf);
clear expn yax ax lh clr yaxlim;

% plot (loads) - log
figland('on');
axes;
hold;
set(gca,'ylim',[0.5 6e4]); % hardwired
set(gca,'yscale','log');
clr = distinguishable_colors(18);
for i = 1:18
    fprintf('plotting source %d: %s\n',i,nam{i});
    lh(i) = plot(ddn,0.001*allTNloads(i,:)); % 1000 lb/yr
    set(lh(i),'color',clr(i,:));
end
datetick;
set(gca,'xlim',[ddn(1) ddn(end)]);
legend(lh,titl,'location','eastoutside');
ylabel('TN Load [1000 lb yr^{-1}]');
grid on;
box on;
%% right y-axis
yaxlim = get(gca,'ylim'); % 1000 lb/yr
yyaxis right;
ax = gca;
yax = ax.YAxis(2);
yax.Scale = 'log';
yax.Limits = yaxlim*453.592;  % kg/yr
pause(5);
expn = double(yax.Exponent);
yax.Limits = yaxlim*453.592/10^expn;
if expn ~= 0
    ylabel(sprintf('TN Load [10^{%d} kg yr^{-1}]',expn));
else
    ylabel('TN Load [kg yr^{-1}]');
end
ax.YAxis(2).Color = 'k';
print -dpng plt/lines-log;
delete(gcf);
clear expn yax ax lh clr yaxlim;

%% 2. one-pagers (so have them all in one place)
% also, this version of makeplot differs from the others:
%   uses black instead of blue, for data points
%   uses 1000 lb yr-1 (isntead of lb yr-1)
for i = 1:18
    makeplot(titl{i},endyr,ddn,allTNloads(i,:),allTNconcs(i,:),allQflows(i,:));
end

%% 3. save data to single mat file, xlsx file, csv file
SourceNames = titl;
SourceNames{end+1} = 'TotalAllSourcesSummed';
dn = ddn;
readme = {  'dn = matlab datenum                                        ';... 
            'TN load [1000 lb yr-1]    (multiply by 453.592 for kg yr-1)';...
            'TN conc [mg L-1]                                           ';...
            'Q (flow) [MGD]            (multiply by 0.043813 for m3 s-1)';};
allTNloads = 0.001*allTNloads;
allTNloads = [allTNloads; sum(allTNloads);];
allQflows = [allQflows; sum(allQflows);];
eval(sprintf(['save dat/%s readme SourceNames dn allTNloads '...
    'allTNconcs allQflows'],outfils_stem));

% save to xlsx
xlsfil = ['dat/' outfils_stem '.xlsx'];
if exist(xlsfil,'file')==2
  delete(xlsfil);
end
readme = table(readme(2:4));
writetable(readme,xlsfil,...
    'Sheet','readme','WriteVariableNames',false);
writetable(table(datestr(dn'),'VariableNames',{'Date'}),...
    xlsfil,'Sheet','TN load');
writetable(table(allTNloads'),...
    xlsfil,'Sheet','TN load','Range',xlsrng,'WriteVariableNames',false);
writetable(table(SourceNames'),...
    xlsfil,'Sheet','TN load','Range','B1:T1','WriteVariableNames',false);
writetable(table(datestr(dn'),'VariableNames',{'Date'}),...
    xlsfil,'Sheet','TN conc');
writetable(table(allTNconcs'),...
    xlsfil,'Sheet','TN conc','Range',xlsrng,'WriteVariableNames',false);
writetable(table(SourceNames'),...
    xlsfil,'Sheet','TN conc','Range','B1:T1','WriteVariableNames',false);
writetable(table(datestr(dn'),'VariableNames',{'Date'}),...
    xlsfil,'Sheet','Q (flow)');
writetable(table(allQflows'),...
    xlsfil,'Sheet','Q (flow)','Range',xlsrng,'WriteVariableNames',false);
writetable(table(SourceNames'),...
    xlsfil,'Sheet','Q (flow)','Range','B1:T1','WriteVariableNames',false);

% end of module
diary off;