% Inventory 

% Create mat file with useful subset of spreadsheet data from each WWTF
%       of interest (EProv, EGwch, Brist, Newp, Jmstwn, Warr, Quon):
%   Flow: Q(avg&max)     [MGD] 
%   Concs [mg/l]:   TN NH4 NO2 NO3 TKN (all avg&max) / NO32 (max only)
%   TN-Load(avg)         [lb/d]

% also make series of plots that graphically show presence/absence:
%       the date ranges and frequencies, for each species

% basic initial setup
wipe;
modprelims;

% retrieve inputs
ingrps = { 'Config'; }; inputsdiary;

% for later
readme = 'Q[MGD];TN/NH4/NO2/NO3/TKN/NO32[mg/L];TNLd[lb/d]';

raw = [];
for ifil = 1:length(fil)

    % read in entire spreadsheet's data
    fprintf('file %d reading data\n',ifil);
    [~,~,traw] = xlsread([fil{ifil}.indir fil{ifil}.infil],...
        fil{ifil}.xlsrng);
    % keep only: facility, Outfall, LSD, Location, Parameter, LimType, 
    %           EndDate, Qualifier, DMR Value, Limit Unit Short Desc
    traw = traw(:,[1 3 4 5 7 12 13 14 15 17]);
    % keep only Outfall='FAC'or'001',LSD='A',Location=1
    % LimType='Q1','Q2','C1','C3'
    % Parameter= 50050(flow) 00600(TN) 00610(NH4) 00615(NO2) 00620(NO3) 
    %       00625(TKN) 00630(NO2+NO3)
    tmp = traw(:,9); % used to screen out zero values other than nitrite
    ind = find( (strcmp(traw(:,2)','001') | strcmp(traw(:,2)','FAC'))... %outfall
                    & strcmp(traw(:,3)','A') ... % LSD 
                    & strcmp(traw(:,4)','1') ... % location
               & (strcmp(traw(:,6)','Q1') | strcmp(traw(:,6)','Q2') ...
                 | (strcmp(traw(:,6)','C1') ) | (strcmp(traw(:,6)','C3') ) ) ...
               & ( strcmp(traw(:,5)','50050') | strcmp(traw(:,5)','00600') ...
                  | strcmp(traw(:,5)','00610') | strcmp(traw(:,5)','00615') ...
                  | strcmp(traw(:,5)','00620') | strcmp(traw(:,5)','00625') ...
                  | strcmp(traw(:,5)','00630') ) ...
                & ~strcmp(traw(:,8)','>') ...
           & ~( ~strcmp(traw(:,5)','00615') & (cellfun(@(v)v(1),tmp)==0)') ) ;
    clear tmp;
    traw = traw(ind,:);
    clear ind;
    % keep only desired years
    yr = datevec(traw(:,7));
    yr = yr(:,1);
    ind = find(yr>=min(fil{ifil}.yrs) & yr<=max(fil{ifil}.yrs));
    traw = traw(ind,:);
    clear yr ind;
    % drop all columns except: facility, Param, LimType, date, qualifier, value
    traw = traw(:,[1 5:9]);    
    % append to raw
    raw = [raw; traw];
    clear traw;
end
clear ifil;

% create diagnostic plot for each facility
begyr = min(fil{1}.yrs);
endyr = max(fil{end}.yrs);
for iw = 1:length(fil{1}.facs)
    fprintf('getting data for %s\n',fil{1}.facs{iw}{1});
    ind = zeros(1,length(raw));
    for ifil = 1:length(fil)
        ind = strcmp(raw(:,1)',fil{ifil}.facs{iw}{2}) | ind;
    end
    ind = find(ind);  
    traw = raw(ind,[2 3 4 5 6]); % param, limtyp, date, qual, val
    clear ind;
    mon = datevec(traw(:,3)); % 
    yr = mon(:,1)';
    mon = mon(:,2)';
    traw = traw(:,[1 2 4 5]); % param limtyp qual val
    [fh,gah] = figport('on');
    for imon = 1:12
        subplot(12,1,imon);
        hold;
        pos = get(gca,'position');
        set(gca,'position',[pos(1) pos(2)-plt.dif pos(3) pos(4)+2*plt.dif]);
        clear pos;
        axis([0 15 begyr-1 endyr+1]);
        set(gca,'xtick',[0:15]);
        if imon == 12
            lbls{16,1} = [];
            lbls(2:15) = strngs;
            set(gca,'xticklabels',lbls)
            xtickangle(90);
        else
            set(gca,'xticklabels',[]);
        end
        ylabel(datestr(datenum(2000,imon,1),'mmm'));
        if imon == 1
            title(fil{ifil}.facs{iw}{1});
        end
        for i = 1:length(clrs)
            % unqualified (solid symbols)
            ind = find( strcmp(traw(:,1)',prms{i}) & ...
                        strcmp(traw(:,2)',limtyps{i}) & ...
                        ( strcmp(traw(:,3)','=') | ...
                            cellfun(@isnan,traw(:,3)') ) & ...
                            mon == imon);
            ph = plot((i)*ones(size(ind)),yr(ind),[symbs{i} clrs{i}]);
            set(ph,'markerfacecolor',clrs{i});
            % qualified (open symbols)
            ind = find( strcmp(traw(:,1)',prms{i}) & ...
                        strcmp(traw(:,2)',limtyps{i}) & ...
                        strcmp(traw(:,3)','>')  & ...
                            mon == imon);
            ph = plot((i+0.25)*ones(size(ind)),yr(ind),[symbs{i} clrs{i}]);
            ind = find( strcmp(traw(:,1)',prms{i}) & ...
                        strcmp(traw(:,2)',limtyps{i}) & ...
                        strcmp(traw(:,3)','<')  & ...
                            mon == imon);
            ph = plot((i-0.25)*ones(size(ind)),yr(ind),[symbs{i} clrs{i}]);
            clear ind ph;
        end
        clear i
    end
    clear imon;
    eval(sprintf('print -dpng plt/%s;',fil{1}.facs{iw}{1}));
    delete(gcf);
    % create matrix of values for downstream modules
    for i = 1:length(nams)
        dat = nan*ones(1,12*(endyr-2000));
        dn = nan*ones(size(dat));
        for iyr = begyr:endyr
            for imon = 1:12
                ind = find( strcmp(traw(:,1)',prms{i}) & ...
                        strcmp(traw(:,2)',limtyps{i}) & ...
                        ~strcmp(traw(:,3)','>') & ...
                        yr == iyr & ...
                        mon == imon); 
                 if length(ind)>1
                     fprintf('more than one value');
                     keyboard;
                 elseif length(ind)==1
                     dat(imon+(iyr-begyr)*12) = traw{ind,4};
                 end 
                 dn(imon+(iyr-begyr)*12) = datenum(iyr,imon,15);
                 clear ind;
            end
            clear imon;
        end
        clear iyr;
        eval(sprintf('%s = dat;',nams{i}));
        clear dat;
    end
    clear i;
    eval(sprintf('save dat/%s readme dn Q TN TNLd NH4 NO2 NO3 TKN NO32;',...
        fil{ifil}.facs{iw}{1}));
    clear dn Q TN TNLd NH4 NO2 NO3 TKN NO32;        
    clear imon yr mon traw;
end
clear iw raw;

% end of module
diary off;