% SomersetLoadCalc

% Compute estimated loads at daily resolution for Somerset
% Save results in a mat file and a plot, using a format uniform 
%      to all 18 sources in the overall analysis.
% Input data: file created from RIDEM spreadsheet by Inventory module.

% notes on methods:

%% Somerset
% No TN available. Used Sum(TKN,NO32), after replacing outliers. Missing 
%   early years filled by mean seasonal cycle of later years. Avg flow 
%   only available during early years; estimated as max flow (available 
%   all years) minus a constant offset determined from the difference 
%   between max flow and avg flow when both measured during early years.

% basic initial setup
wipe;
modprelims;

% retrieve inputs
ingrps = { 'Config'; }; inputsdiary;

%% initial prep
ddn = datenum(2001,1,1):datenum(endyr,12,31); % daily dn
% 1 MGD * mg/L = 8.338 lb/d = 3043 lb/y
newrdme = 'ddn = daily datenum; TNload [lb/y]; TNconc [mg/l]; Qflow [MGD]';
pltdir = ['C:\dc\consult\2020nbep\analysis\NLoad\WWTFs\'...
    'Somerset\SomersetLoadCalc\plt'];

%% Somerset
nam = 'Somerset';
fprintf([nam '\n']);

load([Sindir nam]);
readme = newrdme;
% Concentration [mg/l]
TNconc = filloutliers(NO32.Mx + TKN.Mx,'nearest');
% fill early years using seasonal mean of later years
blck = reshape(TNconc,12,endyr-2000)';
smn = nanmean(blck);
for imon = 1:12
    blck(isnan(blck(:,imon)),imon) = smn(imon);
end
blck = blck';
TNconc = blck(:);
clear smn imon blck;

%   interp from monthly values to daily
TNconc = interp1(dn,TNconc,ddn);
%   fill NaNs in first and last half-month using nearest value
TNconc = fillmissing(TNconc,'nearest');
% Flow [MGD]
Qflow = Q.Av;
Mx = filloutliers(Q.Mx,'nearest'); % remove several notably higher values
Mx = fillmissing(Mx,'linear'); % fill a couple missing dates
offs = nanmean(Mx-Q.Av);
Qflow(isnan(Qflow)) = Mx(isnan(Qflow))-offs;
clear Mx;

%   interp from monthly values to daily
Qflow = interp1(dn,Qflow,ddn);
%   fill NaNs in first and last half-month using nearest value
Qflow = fillmissing(Qflow,'nearest');
% Load [lb/y]
TNload = 3043* TNconc.*Qflow;
eval(sprintf('save dat/%s readme TNload TNconc Qflow ddn;',nam));

makeplot(nam,endyr,ddn,TNload,TNconc,Qflow);

clear dn NH4 NO2 NO3 NO32 Q TKN TNconc TNload Qflow nam readme;

% end of module
diary off;